summaryrefslogtreecommitdiff
path: root/lingucomponent
diff options
context:
space:
mode:
Diffstat (limited to 'lingucomponent')
-rw-r--r--lingucomponent/source/spellcheck/macosxspell/macspellimp.mm4
1 files changed, 2 insertions, 2 deletions
diff --git a/lingucomponent/source/spellcheck/macosxspell/macspellimp.mm b/lingucomponent/source/spellcheck/macosxspell/macspellimp.mm
index 1c7434b45054..ba43a6bcaa7d 100644
--- a/lingucomponent/source/spellcheck/macosxspell/macspellimp.mm
+++ b/lingucomponent/source/spellcheck/macosxspell/macspellimp.mm
@@ -105,7 +105,7 @@ Sequence< Locale > SAL_CALL MacSpellChecker::getLocales()
if (!numdict) {
// invoke a dictionary manager to get the user dictionary list
// TODO How on Mac OS X?
// invoke a second dictionary manager to get the shared dictionary list
NSArray *aSpellCheckLanguages = [[NSSpellChecker sharedSpellChecker] availableLanguages];
@@ -526,7 +526,7 @@ OUString SAL_CALL
MacSpellChecker::getServiceDisplayName( const Locale& /*rLocale*/ )
{
MutexGuard aGuard( GetLinguMutex() );
- return OUString( "Mac OS X Spell Checker" );
+ return OUString( "macOS Spell Checker" );
}
@@ -105,7 +105,7 @@ Sequence< Locale > SAL_CALL MacSpellChecker::getLocales()
if (!numdict) {
// invoke a dictionary manager to get the user dictionary list
- // TODO How on Mac OS X?
+ // TODO How on macOS?
// invoke a second dictionary manager to get the shared dictionary list
NSArray *aSpellCheckLanguages = [[NSSpellChecker sharedSpellChecker] availableLanguages];